@@ -9,9 +9,8 @@ from .device import DeviceKey
 
 @dataclass(frozen=True)
 class BaseValue:
-
     device_key: DeviceKey
-    name: str
+    name: str | None
 
 
 @dataclass(frozen=True)
@@ -33,4 +32,4 @@ class Event(BaseValue):
     """A class that describes device events."""
 
     event_type: str
-    event_subtype: str | None
+    event_properties: dict[str, str | int | float | None] | None
